#pragma once
#include <Windows.h>
#include <map>
#include "window.h"

/**
 * Window allowing us to draw points and lines easily.
 */
class Gui_Window : public Window {
public:
    // Create.
    Gui_Window();

    // Destroy.
    ~Gui_Window();

    // Draw a number of points.
    void draw(const std::vector<Point> &points) override;

    // Draw a line.
    void draw(Point from, Point to) override;

    // Run the main-loop until the window is closed.
    void run() override;

private:
    // The window itself.
    HWND window;

    // Points we need to draw.
    std::vector<Point> points;

    // Lines we need to draw.
    std::vector<Point> lines;

    // Border around the "active" area, in pixels.
    static inline const int border = 5;

    // Size of the window in pixels.
    static inline const int window_size = 512;

    // Maximum coordinate size.
    static inline const int max_coord = 32767;

    // Transform a point.
    Point transform(Point p);

    // Redraw the window.
    void draw();

    // Handle events.
    void check_events();

    // Background brush.
    HBRUSH background;

    // Pen used for lines.
    HPEN linePen;

    // Bookkeeping.
    static std::map<HWND, Gui_Window *> open_windows;
    static ATOM window_class;

    // Callback from Windows.
    static LRESULT CALLBACK window_proc(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam);
};
